@@ -71,6 +71,8 @@ struct _GokWordCompleteClass
 				    const gchar *utf8_word);
 	gboolean  (* increment_word_frequency) (GokWordComplete *complete,
 						const gchar *word);
+	gboolean  (* validate_word) (GokWordComplete *complete,
+				     const gchar *utf8_word);
 
 	/* private use */
 	gchar*    (* unichar_pop) (GokWordComplete *complete);
@@ -91,6 +93,7 @@ gchar**  gok_wordcomplete_predict_string (GokWordComplete *complete, const gchar
 					  gint num_predictions);
 
 gboolean gok_wordcomplete_add_new_word   (GokWordComplete *complete, const char* word);
+gboolean gok_wordcomplete_validate_word  (GokWordComplete *complete, const char* word);
 
 GokWordComplete *gok_wordcomplete_get_default (void);
 gchar**  gok_wordcomplete_process_and_predict (GokWordComplete *complete, const gunichar letter, 
